import { Component, OnInit } from '@angular/core';
import { FormBuilder, FormGroup, Validators } from '@angular/forms';
import { MatDialogRef } from '@angular/material/dialog';

@Component({
  selector: 'app-create-client',
  templateUrl: './create-client.component.html',
  styleUrls: ['./create-client.component.css']
})
export class CreateClientComponent implements OnInit {
  clientForm!: FormGroup;

  constructor(
    private fb: FormBuilder,
    private dialogRef: MatDialogRef<CreateClientComponent>
  ) { }

  ngOnInit(): void {
    this.clientForm = this.fb.group({
      name: ['', Validators.required],
      serialNumber: ['', Validators.required],
      netiface: [''],
      netDriver: [''],
      mac: ['', [Validators.required, Validators.pattern('^([0-9A-Fa-f]{2}[:-]){5}([0-9A-Fa-f]{2})$')]],
      ip: ['', [Validators.required, Validators.pattern('^([0-9]{1,3}\.){3}[0-9]{1,3}$')]],
      status: [''],
      organizationalUnit: ['', Validators.pattern('https?://.+')],
      menu: ['', Validators.pattern('https?://.+')],
      hardwareProfile: ['', Validators.pattern('https?://.+')],
    });
  }

  onSubmit() {
    if (this.clientForm.valid) {
      const formData = this.clientForm.value;
      console.log('Form Data:', formData);
      this.dialogRef.close(formData);
    }
  }

  onNoClick(): void {
    this.dialogRef.close();
  }
}
