import { Injectable } from '@angular/core';
import { HttpClient } from '@angular/common/http';
import { Observable, throwError } from 'rxjs';
import { catchError, map } from 'rxjs/operators';
import { UnidadOrganizativa } from './model';

@Injectable({
  providedIn: 'root'
})
export class DataService {

  private apiUrl = 'http://127.0.0.1:8080/organizational-units?page=1&itemsPerPage=30';
  private clientsUrl = 'http://127.0.0.1:8080/clients?page=1&itemsPerPage=30';

  constructor(private http: HttpClient) {}

  getUnidadesOrganizativas(): Observable<UnidadOrganizativa[]> {
    return this.http.get<any>(this.apiUrl).pipe(
      map(response => {
        if (response['hydra:member'] && Array.isArray(response['hydra:member'])) {
          return response['hydra:member']
            .filter((unidad: any) => unidad.type === 'organizational-unit')
            .map((unidad: any) => ({
              id: unidad.id,
              nombre: unidad.name,
              uuid: unidad.uuid,
              type: unidad.type,
              aulas: []
            }));
        } else {
          throw new Error('Unexpected response format');
        }
      }),
      catchError(error => {
        console.error('Error fetching unidades organizativas', error);
        return throwError(error);
      })
    );
  }

  getChildren(uuid: string): Observable<any[]> {
    return this.http.get<any>(`${this.apiUrl}&parent=${uuid}`).pipe(
      map(response => {
        if (response['hydra:member'] && Array.isArray(response['hydra:member'])) {
          return response['hydra:member'].filter((element: any) => element.parent && element.parent['@id'] === `/organizational-units/${uuid}`);
        } else {
          throw new Error('Unexpected response format');
        }
      }),
      catchError(error => {
        console.error('Error fetching children', error);
        return throwError(error);
      })
    );
  }

  getClients(uuid: string): Observable<any[]> {
    console.log('unidadId', uuid);
    return this.http.get<any>(this.clientsUrl).pipe(
      map(response => {
        if (response['hydra:member'] && Array.isArray(response['hydra:member'])) {
          return response['hydra:member'].filter((client: any) => client.organizationalUnit && client.organizationalUnit['@id'] === `/organizational-units/${uuid}`);
        } else {
          throw new Error('Unexpected response format');
        }
      }),
      catchError(error => {
        console.error('Error fetching clients', error);
        return throwError(error);
      })
    );
  }


}
