import { Component, OnInit } from '@angular/core';
import { DataService } from './data.service';
import { UnidadOrganizativa } from './model';
import { MatDialog } from '@angular/material/dialog';
import { CreateOrganizationalUnitComponent } from './organizational-units/create-organizational-unit/create-organizational-unit.component';

@Component({
  selector: 'app-groups',
  templateUrl: './groups.component.html',
  styleUrls: ['./groups.component.css']
})
export class GroupsComponent implements OnInit {
  unidadesOrganizativas: UnidadOrganizativa[] = [];
  selectedUnidad: UnidadOrganizativa | null = null;
  children: any[] = [];
  breadcrumb: string[] = [];

  constructor(private dataService: DataService, public dialog: MatDialog) {}

  ngOnInit(): void {
    this.dataService.getUnidadesOrganizativas().subscribe(
      data => this.unidadesOrganizativas = data,
      error => console.error('Error fetching unidades organizativas', error)
    );
  }

  onSelectUnidad(unidad: UnidadOrganizativa): void {
    this.selectedUnidad = unidad;
    this.breadcrumb = [unidad.nombre];
    this.loadChildrenAndClients(unidad.uuid);
  }

  onSelectChild(child: any): void {
    if (child.uuid && child.id) {
      this.breadcrumb.push(child.name || child.nombre);
      this.loadChildrenAndClients(child.uuid);
    }
  }

  loadChildrenAndClients(uuid: string): void {
    this.dataService.getChildren(uuid).subscribe(
      childrenData => {
        this.dataService.getClients(uuid).subscribe(
          clientsData => {
            const newChildren = [...childrenData, ...clientsData];
            if (newChildren.length > 0) {
              this.children = newChildren;
            } else {
              // No se encontraron elementos hijos o clientes, revertimos el breadcrumb
              this.breadcrumb.pop();
            }
          },
          error => console.error('Error fetching clients', error)
        );
      },
      error => console.error('Error fetching children', error)
    );
  }


  addOU(): void {
    this.dialog.open(CreateOrganizationalUnitComponent);
  }

  getIcon(type: string): string {
    switch(type) {
      case 'organizational-unit':
        return 'apartment';
      case 'classroom-group':
        return 'classrooms-group-icon';
      case 'classroom':
        return 'classroom-icon';
      case 'client':
        return 'client-icon';
      case 'clients-group':
        return 'clients-group-icon';
      default:
        return '';
    }
  }

  onDeleteClick(uuid: string): void {
    console.log('UUID del elemento a eliminar:', uuid);
    // Aquí puedes agregar lógica adicional para eliminar el elemento si es necesario
  }

  onEditClick(type: any, uuid: string): void {
    console.log('Tipo del elemento a editar:', type);
    console.log('UUID del elemento a editar:', uuid);
    // Aquí puedes agregar lógica adicional para editar el elemento si es necesario
  }
}
