import { Component, OnInit } from '@angular/core';
import { FormBuilder, FormGroup, Validators } from '@angular/forms';
import { MatDialogRef } from '@angular/material/dialog';

@Component({
  selector: 'app-create-organizational-unit',
  templateUrl: './create-organizational-unit.component.html',
  styleUrls: ['./create-organizational-unit.component.css']
})
export class CreateOrganizationalUnitComponent implements OnInit {
  isLinear = true;
  generalFormGroup: FormGroup;
  additionalInfoFormGroup: FormGroup;
  networkSettingsFormGroup: FormGroup;
  types: string[] = ['organizational-unit', 'classrooms-group', 'classroom', 'clients-group'];

  constructor(
    private _formBuilder: FormBuilder,
    private dialogRef: MatDialogRef<CreateOrganizationalUnitComponent>
  ) {
    this.generalFormGroup = this._formBuilder.group({
      name: ['', Validators.required],
      parent: ['', Validators.required],
      description: [''],
      type: ['', Validators.required]
    });
    this.additionalInfoFormGroup = this._formBuilder.group({
      comments: [''],
    });
    this.networkSettingsFormGroup = this._formBuilder.group({
      proxy: [''],
      dns: [''],
      netmask: [''],
      router: [''],
      ntp: [''],
      p2pMode: [''],
      p2pTime: [0, Validators.min(0)],
      mcastIp: [''],
      mcastSpeed: [0, Validators.min(0)],
      mcastPort: [0, Validators.min(0)],
      mcastMode: [''],
      menu: ['', Validators.pattern('https?://.+')],
      hardwareProfile: ['', Validators.pattern('https?://.+')],
      validation: [false]
    });
  }

  ngOnInit() {}

  onSubmit() {
    if (this.generalFormGroup.valid && this.additionalInfoFormGroup.valid && this.networkSettingsFormGroup.valid) {
      const formData = {
        ...this.generalFormGroup.value,
        ...this.additionalInfoFormGroup.value,
        ...this.networkSettingsFormGroup.value,
      };
      console.log('Form Data:', formData);
      this.dialogRef.close(formData);
    }
  }

  onNoClick(): void {
    this.dialogRef.close();
  }
}
