import { Component, OnInit } from '@angular/core';
import { RoleService } from './roles.service';
import { MatTableDataSource } from '@angular/material/table';
import { MatDialog } from '@angular/material/dialog';
import { AddRoleModalComponent } from './add-role-modal/add-role-modal.component';
import { DeleteRoleModalComponent } from './delete-role-modal/delete-role-modal.component';

@Component({
  selector: 'app-roles',
  templateUrl: './roles.component.html',
  styleUrls: ['./roles.component.css']
})
export class RolesComponent implements OnInit {
  dataSource = new MatTableDataSource<any>();
  columns = [
    {
      columnDef: 'id',
      header: 'ID',
      cell: (role: any) => `${role.id}`
    },
    {
      columnDef: 'name',
      header: 'Nombre',
      cell: (role: any) => `${role.name}`
    },
    {
      columnDef: 'permissions',
      header: 'Permisos',
      cell: (role: any) => `${role.permissions.join(', ')}`
    }
  ];
  displayedColumns = [...this.columns.map(column => column.columnDef), 'actions'];

  constructor(private roleService: RoleService, public dialog: MatDialog) {}

  ngOnInit() {
    this.loadRoles();
  }

  loadRoles() {
    this.roleService.getRoles().subscribe(response => {
      console.log(response);
      this.dataSource.data = response['hydra:member'];
    });
  }

  addUser() {
    const dialogRef = this.dialog.open(AddRoleModalComponent);

    /* dialogRef.componentInstance.roleAdded.subscribe(() => {
      this.loadRoles();
    }); */

  }

  deleteRole(role: any) {
    const dialogRef = this.dialog.open(DeleteRoleModalComponent, {
      data: role
    });

    dialogRef.afterClosed().subscribe(result => {
      if (result) {
        this.loadRoles();
      }
    });
  }
}
