import { Component, EventEmitter, Inject, Output } from '@angular/core';
import { FormGroup, FormBuilder, Validators } from '@angular/forms';
import { MatDialogRef, MAT_DIALOG_DATA } from '@angular/material/dialog';
import { EditUserModalComponent } from '../edit-user-modal/edit-user-modal.component';
import { UserService } from '../users.service';

@Component({
  selector: 'app-change-password-modal',
  templateUrl: './change-password-modal.component.html',
  styleUrl: './change-password-modal.component.css'
})
export class ChangePasswordModalComponent {
  @Output() userEdited = new EventEmitter<void>();
  userForm: FormGroup;
  passwordMismatch: boolean = false;
  updateError: boolean = false;

  constructor(
    public dialogRef: MatDialogRef<EditUserModalComponent>,
    @Inject(MAT_DIALOG_DATA) public data: any,
    private fb: FormBuilder,
    private userService: UserService
  ) {
    this.userForm = this.fb.group({
      username: [this.data.user, Validators.required],
      password: ['', Validators.required],
      confirmPassword: ['', Validators.required]
    }, { validators: this.passwordMatchValidator });
  }

  ngOnInit(): void {
    console.log('Data:', this.data);
  }

  onNoClick(): void {
    this.dialogRef.close();
  }

  onSubmit(): void {
    if (this.userForm.valid) {
      this.passwordMismatch = false;
      this.updateError = false;

      const userPayload = {
        username: this.userForm.value.username,
        allowedOrganizationalUnits: [],
        password: this.userForm.value.password,
        enabled: true,
        userGroups: []
      };
      console.log("THIS IS THE USER PAYLOAD: ", userPayload);
      this.userService.updateUser(this.data.uuid, userPayload).subscribe(
        response => {
          console.log('User updated successfully:', response);
          this.userEdited.emit();
          this.dialogRef.close(this.userForm.value);
        },
        error => {
          console.error('Error updating user:', error);
          this.updateError = true;
        }
      );
    } else {
      console.error('Form is invalid');
      this.passwordMismatch = this.userForm.hasError('mismatch');
      this.updateError = true;
    }
  }

  private passwordMatchValidator(form: FormGroup): { [key: string]: boolean } | null {
    return form.get('password')?.value === form.get('confirmPassword')?.value ? null : { mismatch: true };
  }
}
