import { Component, EventEmitter, Inject, OnInit, Output } from '@angular/core';
import { FormBuilder, FormGroup, Validators } from '@angular/forms';
import { MAT_DIALOG_DATA, MatDialogRef } from '@angular/material/dialog';
import { UserService } from '../users.service';

interface UserGroup {
  '@id': string;
  name: string;
  role: string[];
}

@Component({
  selector: 'app-edit-user-modal',
  templateUrl: './edit-user-modal.component.html',
  styleUrls: ['./edit-user-modal.component.css']
})
export class EditUserModalComponent implements OnInit {@Output() userEdited = new EventEmitter<void>();
  userForm: FormGroup;
  userGroups: UserGroup[] = [];
  organizationalUnits: any[] = [];

  constructor(
    public dialogRef: MatDialogRef<EditUserModalComponent>,
    @Inject(MAT_DIALOG_DATA) public data: any,
    private fb: FormBuilder,
    private userService: UserService // Inyecta el servicio
  ) {
    this.userForm = this.fb.group({
      username: [this.data],
      password: [''],
      role: this.data.user.allowedOrganizationalUnits,
      organizationalUnit: [[this.data.user.allowedOrganizationalUnits], Validators.required]
    });
  }

  ngOnInit(): void {
    this.userService.getUserGroups().subscribe((data) => {
      this.userGroups = data['hydra:member'];
    });
    this.userService.getOrganizationalUnits().subscribe((data) => {
      this.organizationalUnits = data['hydra:member'];
    });
  }

  onNoClick(): void {
    this.dialogRef.close();
  }

  onSubmit(): void {

      const userPayload = {
        username: this.userForm.value.username,
        allowedOrganizationalUnits: [],
        password: this.userForm.value.password,
        enabled: true,
        userGroups: [this.userForm.value.role ]
      };

      this.userService.updateUser(this.data.user.uuid, userPayload).subscribe(
        response => {
          console.log('User added successfully:', response);
          this.userEdited.emit();
          this.dialogRef.close(this.userForm.value);
        },
        error => {
          console.error('Error adding user:', error);
          // Agregar alguna lógica para manejar el error en la interfaz de usuario
        }
      );
  }
}
