import { Component, OnInit } from '@angular/core';
import { UserService } from './users.service';
import { MatTableDataSource } from '@angular/material/table';
import { DeleteUserModalComponent } from './delete-user-modal/delete-user-modal.component';
import { MatDialog } from '@angular/material/dialog';
import { AddUserModalComponent } from './add-user-modal/add-user-modal.component';
import { EditUserModalComponent } from './edit-user-modal/edit-user-modal.component';

@Component({
  selector: 'app-users',
  templateUrl: './users.component.html',
  styleUrls: ['./users.component.css']
})
export class UsersComponent implements OnInit {
  dataSource = new MatTableDataSource<any>();
  columns = [
    {
      columnDef: 'id',
      header: 'ID',
      cell: (user: any) => `${user.id}`
    },
    {
      columnDef: 'username',
      header: 'Nombre de Usuario',
      cell: (user: any) => `${user.username}`
    },
    {
      columnDef: 'allowedOrganizationalUnits',
      header: 'Unidades Organizacionales Permitidas',
      cell: (user: any) => `${user.allowedOrganizationalUnits.map((unit: { name: any; }) => unit.name).join(', ')}`
    },
    {
      columnDef: 'roles',
      header: 'Roles',
      cell: (user: any) => `${user.roles.join(', ')}`
    }
  ];
  displayedColumns = [...this.columns.map(column => column.columnDef), 'actions'];

  constructor(private userService: UserService, public dialog: MatDialog) {}

  ngOnInit() {
    this.loadUsers();
  }

  loadUsers() {
    this.userService.getUsers().subscribe(response => {
      this.dataSource.data = response['hydra:member'];
      console.log(this.dataSource.data);
    });
  }

  addUser() {
    const dialogRef = this.dialog.open(AddUserModalComponent);

    dialogRef.componentInstance.userAdded.subscribe(() => {
      this.loadUsers();
    });

  }

  editUser(user: any) {
    // Implementar la lógica de edición
    const dialogRef = this.dialog.open(EditUserModalComponent, {
      data: { user: user }
    });
    dialogRef.componentInstance.userEdited.subscribe(() => {
      this.loadUsers();
    });
  }

  deleteUser(user: any) {
    const dialogRef = this.dialog.open(DeleteUserModalComponent, {
      data: user
    });

    dialogRef.afterClosed().subscribe(result => {
      if (result) {
        this.loadUsers();
      }
    });
  }
}
